/**********************************************************************

	--- Qt Architect generated file ---

	File: mimetypes.cpp
	Last generated: Wed Nov 28 21:02:04 2001

 *********************************************************************/

#include "mimetypes.h"
#include <kmimetype.h>
#include <klineeditdlg.h>
#include <qvaluelist.h>
#include <qlist.h>

#define Inherited MimeTypesData

MimeTypes::MimeTypes(QWidget* parent,	const char* name)
	:	Inherited( parent, name )
{
//  debug("Mimetypes::Mimetypes()");
  KMimeType::List l=KMimeType::allMimeTypes();

  KMimeType::List::Iterator it1;
  for(it1 = l.begin(); it1 != l.end(); ++it1 )
    list.append(new QString((*it1)->name()));
  list.sort();

  KGlobal::config()->setGroup("Convert2Text");

  QListIterator<QString> it2(list);
  for(; it2.current(); ++it2 )
    mimetypelist->insertItem( *(*it2)+" : "+KGlobal::config()->readEntry( *(*it2), "-"));

  KGlobal::config()->setGroup("");
}


void MimeTypes::slotSelected(int i)
{
  bool b;
  KGlobal::config()->setGroup("Convert2Text");
  QString s=KLineEditDlg::getText("Command (type '-' to clear commandline): ", KGlobal::config()->readEntry( *list.at(i), ""), &b, this);
  if(b) {
    if(s=="-") {
      KGlobal::config()->deleteEntry(*list.at(i));
      mimetypelist->changeItem(*list.at(i)+" : -", i);
    }
    else {
      KGlobal::config()->writeEntry(*list.at(i), s);
      mimetypelist->changeItem(*list.at(i)+" : "+s, i);
    }
  }
  KGlobal::config()->setGroup("");
}


void MimeTypes::slotClose()
{
  close();
}


MimeTypes::~MimeTypes()
{
}
